@@ -14,6 +14,8 @@
 
 #include "config.h"
 
+#include <string.h>
+
 #ifdef HAVE_LIBDES
 
 #include <stdio.h>
@@ -158,8 +160,8 @@ decrypt_packet(unsigned char *packet)
     date_in_sec = ntohl(r.fields.date);
     date_in_ascii = ctime(&date_in_sec);
     
-    *SGADDRP(ip_local) = r.fields.ip_local;
-    *SGADDRP(ip_remote) = r.fields.ip_remote;
+    memcpy(SGADDRP(ip_local), &(r.fields.ip_local), sizeof(ip_local));
+    memcpy(SGADDRP(ip_remote), &(r.fields.ip_remote), sizeof(ip_remote));
 
     /* FIXME: uid_t isn't necessarily short.  */
 #ifdef HAVE_SNPRINTF
@@ -167,7 +169,7 @@ decrypt_packet(unsigned char *packet)
 #else
     sprintf(readable,
 #endif
-	    "%24.24s %u ",
+            "%24.24s %u %s %u %s %u",
 	    date_in_ascii,
 	    ntohs(r.fields.uid),
 	    s_inet_ntox(&ip_local, buf1, sizeof(buf1)),
