@@ -65,7 +65,37 @@ ka_lookup(void *vp, struct kernel *kp)
     long r_laddr, r_raddr, myladdr, myraddr;
     int r_lport, r_rport, mylport, myrport;
     int euid;
+    int nra;
     
+/*
+ * PSz 11 Dec 02
+ * 
+ * We have observed Debian identd (on a fairly busy dual-CPU machine)
+ * sometimes reporting 'root' for connections belonging to "real" users.
+ * File /proc/net/tcp is written mostly in routine get__sock in
+ * /usr/src/kernel-source-2.2.19/net/ipv4/proc.c :
+ * 
+ * 	sprintf(tmpbuf, "%4d: %08lX:%04X %08lX:%04X"
+ * 		" %02X %08X:%08X %02X:%08lX %08X %5d %8d %lu",
+ * 		i, src, srcp, dest, destp, sp->state, 
+ * 		(tw_bucket ?
+ * 		 0 :
+ * 		 (format == 0) ?
+ * 		 tp->write_seq-tp->snd_una : atomic_read(&sp->wmem_alloc)),
+ * 		(tw_bucket ?
+ * 		 0 :
+ * 		 (format == 0) ?
+ * 		 tp->rcv_nxt-tp->copied_seq: atomic_read(&sp->rmem_alloc)),
+ * 		timer_active, timer_expires-jiffies,
+ * 		(tw_bucket ? 0 : tp->retransmits),
+ * 		(!tw_bucket && sp->socket) ? sp->socket->inode->i_uid : 0,
+ * 		(!tw_bucket && timer_active) ? sp->timeout : 0,
+ * 		(!tw_bucket && sp->socket) ? sp->socket->inode->i_ino : 0);
+ * 
+ * Should we skip lines with just ino, or both uid and ino, zero?
+ */
+    unsigned long int ino;
+
     
     r_rport = ntohs(kp->remote.sin_port);
     r_lport = ntohs(kp->local.sin_port);
@@ -83,14 +113,23 @@ ka_lookup(void *vp, struct kernel *kp)
 
     while (fgets(buf, sizeof(buf)-1, fp) != NULL)
     {
-	if (sscanf(buf, "%d: %lX:%x %lX:%x %x %lX:%lX %x:%lX %lx %d %ld %d",
-		   &dummy, &myladdr, &mylport, &myraddr, &myrport,
-		   &dummy, &dummy, &dummy, &dummy, &dummy, &dummy,
-		   &euid, &dummy, &dummy) >= 12)
+	nra = sscanf(buf, "%d: %lX:%x %lX:%x %x %lX:%lX %x:%lX %lx %d %ld %lu",
+		     &dummy, &myladdr, &mylport, &myraddr, &myrport,
+		     &dummy, &dummy, &dummy, &dummy, &dummy, &dummy,
+		     &euid, &dummy, &ino);
+	if (nra >= 12)
 	{
 	    if (myladdr == r_laddr && mylport == r_lport &&
 		myraddr == r_raddr && myrport == r_rport)
 	    {
+		if (nra >= 14 && euid == 0 && ino == 0) {
+		  /*
+		   * Both uid and ino are zero: not even a socket?
+		   * Skip (continue), probably fail; or fail (break)
+		   * straight away? Hopefully we retry later.
+		   */
+		  continue;
+		}
 		kp->euid = euid;
 		return 1;
 	    }
