@@ -125,6 +125,28 @@ ka_init(void)
 }
 
 
+/*
+** Get a piece of kernel memory with error handling.
+** Returns 1 if call succeeded, else 0 (zero).
+*/
+static int
+getbuf(kvm_t *kd, off_t addr, char *buf, size_t len, char *what)
+{
+    int i;
+    ssize_t status;
+    
+    
+    i = 0;
+    while (i < 5 && (status = kvm_read(kd, addr, buf, len)) < 0)
+	++i;
+    
+    if (status < 0)
+	return 0;
+    
+    return 1;
+}
+
+
 /*
 ** Open kernel devices, lookup kernel symbols etc... 
 */
@@ -165,9 +187,9 @@ ka_open(void **misc)
     /*
      * Read the two kernel values we need but won't change
      */
-    if (!getbuf(kp->kd, kp->nl[N_HASH_SIZE].n_value, &kp->hash_size,
+    if (!getbuf(kp->kd, kp->nl[N_HASH_SIZE].n_value, (char *) &kp->hash_size,
 	    sizeof(kp->hash_size), kp->nl[N_HASH_SIZE].n_name) ||
-	!getbuf(kp->kd, kp->nl[N_FANOUT].n_value, &kp->hash_table,
+	!getbuf(kp->kd, kp->nl[N_FANOUT].n_value, (char *) &kp->hash_table,
 	sizeof(kp->hash_table), kp->nl[N_FANOUT].n_name)) {
 	    kvm_close(kp->kd);
 	    s_free(kp);
@@ -180,28 +202,6 @@ ka_open(void **misc)
 }
 
 
-/*
-** Get a piece of kernel memory with error handling.
-** Returns 1 if call succeeded, else 0 (zero).
-*/
-static int
-getbuf(kvm_t *kd, off_t addr, char *buf, size_t len, char *what)
-{
-    int i;
-    ssize_t status;
-    
-    
-    i = 0;
-    while (i < 5 && (status = kvm_read(kd, addr, buf, len)) < 0)
-	++i;
-    
-    if (status < 0)
-	return 0;
-    
-    return 1;
-}
-
-
 /*
 ** Return the user number for the connection owner
 */
