@@ -21,7 +21,7 @@
 struct request
 {
     int fd;
-    struct sockaddr_in addr;
+    struct sockaddr_gen addr;
     socklen_t addr_len;
 };
 
