@@ -23,6 +23,7 @@
 
 #include <sys/types.h>
 #include <netinet/in.h>
+#include <arpa/inet.h>
 
 #include "pidentd.h"
 
@@ -461,19 +462,24 @@ syslog_str2fac(const char *name)
 
 
 /*
-** An MT-safe version of inet_ntoa() for IPv4
+** An MT-safe version of inet_ntoa() for IPv4/inet_ntop() for IPv6 (is safe)
 */
-char *
-s_inet_ntoa(struct in_addr ia,
+const char *
+s_inet_ntox(struct sockaddr_gen *ia,
 	    char *buf,
 	    size_t bufsize)
 {
+
+#ifdef HAVE_IPV6
+    return inet_ntop(SGFAM(*ia), SGADDRP(*ia), buf, bufsize);
+#else
     unsigned char *bp;
 
-    bp = (unsigned char *) &ia;
+    bp = (unsigned char *) SGADDRP(*ia);
     
     if (s_snprintf(buf, bufsize, "%u.%u.%u.%u", bp[0], bp[1], bp[2], bp[3]) < 0)
 	return NULL;
 
     return buf;
+#endif
 }
